@@ -1,19 +1,19 @@
 from lxml.html import document_fromstring
-from purifier.purifier import HTMLPurifier
+# from purifier.purifier import HTMLPurifier
 
 
 class Static:
 
-    @staticmethod
-    def _clear_html(body):
-        purifier = HTMLPurifier({
-            'div': ['*'], 'span': ['*'],
-            'img': ['*'], 'a': ['*'],
-            'h1': ['*'], 'h2': ['*'],
-            'h3': ['*'], 'h4': ['*'],
-            'h5': ['*'], 'h6': ['*'],
-        })
-        return purifier.feed(body)
+    # @staticmethod
+    # def _clear_html(body):
+    #     purifier = HTMLPurifier({
+    #         'div': ['*'], 'span': ['*'],
+    #         'img': ['*'], 'a': ['*'],
+    #         'h1': ['*'], 'h2': ['*'],
+    #         'h3': ['*'], 'h4': ['*'],
+    #         'h5': ['*'], 'h6': ['*'],
+    #     })
+    #     return purifier.feed(body)
 
     @staticmethod
     def document_fromstring(body, selector: str = None, idx: int = None):  # pragma: no cover
