@@ -4,9 +4,6 @@ from .helpers.std import Std
 
 class PsychoPlayCo(Provider, Std):
 
-    def get_archive_name(self) -> str:
-        return self.normal_arc_name(self.get_chapter_index())
-
     def get_chapter_index(self) -> str:
         ch = self.chapter
         idx = self.re.search('/read/[^/]+/([^/]+)', ch)
