@@ -1,8 +1,8 @@
 from .helpers.std import Std
-from .rawdevart_com import RawDevArtCom
+from .rawdevart_com_old import RawDevArtComOld
 
 
-class RawNekoCom(RawDevArtCom, Std):
+class RawNekoCom(RawDevArtComOld, Std):
     _chapter_selector = r'/chapter-(\d+(?:-\d+)?)'
 
 
